@@ -1,4 +1,5 @@
 from discord.ext import commands
+from Daug.functions import excepter
 from Daug.functions.embeds import compose_embed_from_description
 
 
@@ -8,6 +9,7 @@ class Utils(commands.Cog):
         self.id = self.bot.config['Daug']['guild_id']
 
     @commands.command(aliases=['ch'])
+    @excepter
     async def channel_count(self, ctx):
         count = len(ctx.guild.channels)
         await ctx.channel.send(embed=compose_embed_from_description(f'チャンネル数:{count}'))
